@@ -1,25 +1,17 @@
 import numpy as np
 from nupropagator.cross_section import cross as cs
+#from cross_section import cross as cs
 from nupropagator.cross_section import cross_ground as cg
+#from cross_section import cross_ground as cg
 from nudisxs.disxs import *
 from scipy.spatial.transform import Rotation as R
 
 class NuGen:
     def __init__(self):
-        self.pdf_model = opts.neutrinoPrimary_pdf_model
         self.nu_energy_GeV = 0.
         self.nu_direction  = [0.,0.,1.]
         self.target        = -1 # not possible value. must be configured
         self.current = {-1: 'nc', 1: 'cc'}
-        self.cs_p = cs.Cross_section(self.pdf_model,14,2212)
-        self.cs_n = cs.Cross_section(self.pdf_model,14,2112)
-        self.cross_ground_p_NC = cg.cross_ground(self.pdf_model,'nc',self.nu_pdg,2212)
-        self.cross_ground_n_NC = cg.cross_ground(self.pdf_model,'nc',self.nu_pdg,2112)
-        self.cross_ground_p_CC = cg.cross_ground(self.pdf_model,'cc',self.nu_pdg,2212)
-        self.cross_ground_n_CC = cg.cross_ground(self.pdf_model,'cc',self.nu_pdg,2112)
-        self.cross_ground = {(1,2112): self.cross_ground_n_CC.f, (1,2212): self.cross_ground_p_CC.f,
-                 (-1,2112): self.cross_ground_n_NC.f, (-1,2212): self.cross_ground_p_NC.f}
-        self.xsec_xy = {1: self.dis.xs_cc, -1: self.dis.xs_nc}
 
     def configure(self,opts):
         self.configure_simulation_mode(opts)
@@ -40,6 +32,16 @@ class NuGen:
 
     def configure_neutrino(self,opts):
         self.nu_pdg = opts.neutrinoPrimary_pdgid
+        self.cs_p = cs.Cross_section(self.pdf_model,14,2212)
+        self.cs_n = cs.Cross_section(self.pdf_model,14,2112)
+        self.cross_ground_p_NC = cg.cross_ground(self.pdf_model,'nc',self.nu_pdg,2212)
+        self.cross_ground_n_NC = cg.cross_ground(self.pdf_model,'nc',self.nu_pdg,2112)
+        self.cross_ground_p_CC = cg.cross_ground(self.pdf_model,'cc',self.nu_pdg,2212)
+        self.cross_ground_n_CC = cg.cross_ground(self.pdf_model,'cc',self.nu_pdg,2112)
+        self.cross_ground = {(1,2112): self.cross_ground_n_CC.f, (1,2212): self.cross_ground_p_CC.f,
+                 (-1,2112): self.cross_ground_n_NC.f, (-1,2212): self.cross_ground_p_NC.f}
+        self.xsec_xy = {1: self.dis.xs_cc, -1: self.dis.xs_nc}
+
         if self.nu_energy_mode != 'random':
             self.nu_energy_GeV = opts.neutrinoPrimary_energy_GeV
         if self.nu_direction_mode != 'random':
@@ -166,9 +168,9 @@ class NuGen:
         final_nucleon = [self.dis.particles[1]['pdgid'],self.dis.particles[1]['Px_GeV'],self.dis.particles[1]['Py_GeV'],self.dis.particles[1]['Pz_GeV'],self.dis.particles[1]['E_GeV']]
         return final_lepton,final_nucleon
 
-    def get_event(self):
+    def get_event(self,opts):
         # get neutrino energy
-        self.dis.init_neutrino(self.nu_pdg)
+        self.configure(opts)
         nu_cos, nu_sin, nu_phi = self.get_neutrino_direction()
         nu_energy = self.get_neutrino_energy()
         self.get_target()
@@ -176,8 +178,9 @@ class NuGen:
         x,y = self.get_xy_Bjorken(mode)
         return self.get_particles_momenta(x, y, nu_cos, nu_sin, nu_phi)
 
-    def get_event_fix_en(self):
-        self.dis.init_neutrino(self.nu_pdg)
+    def get_event_fix_en(self,opts):
+        #self.dis.init_neutrino(self.nu_pdg)
+        self.configure(opts)
         nu_cos, nu_sin, nu_phi = self.get_neutrino_direction()
         nu_energy = self.get_neutrino_energy()
         self.get_target()
